#!/usr/bin/env perl
# plantbreak.pl
#
# I want to do comparing analysis for the words preceding a
# "plant break" and the "normal" words. This is a script which
# will count these classes of words.
#
# My analysis uses the full transcription by Takeshi Takahashi,
# which I extracted from Jorge Stolfi's interlinear archive with
# my "viat" tool. The command line was:
#
# viat -t H -i H | perl plantbreak.pl
#
# If you want to use another transcription, just change the
# parameters. But it is important that your transcription has
# these {plant} inline comments...
#
# Elias Schwerdtfeger
# http://voynich.tamagothi.de/


use strict;
use warnings;


my ($line, %bplant, %all);


while ($line = <>)
{
    my ($word);

    # Remove locator, tailing whitespace and newline
    chomp $line;
    $line =~ s/^\<[^\>]+\>\s*//;

    # Count words preceding a "plant break"
    # -------------------------------------

    # Parse words before the "plant breaks" and count them
    while ($line =~ m/[\.,\-=]([a-z\*]+)([\-=])\{plant\}/g)
    {
	# Get the word and the - or = after the word.
	# (Eventually I want to use the -/= in later analysis...)
	my ($word, $separator) = ($1, $2);
	# Ignore illegible words
	next if $word =~ /\*/;
	# Count the word
	$bplant{$word}++;
    }

    # Count all words for comparision
    # -------------------------------

    # At first, remove all inline comments from the line, to make
    # the following processing easier.
    $line =~ s/\{[^\}]*\}//g;
    
    # Split the line and count the words
    foreach $word (split /[.,\-=]/, $line)
    {
	# Ignore illegible words
	next if $word =~ /\*/;
	$all{$word}++;
    }
}


my ($word, $cnt);


# Print the words that precede plant breaks into bplant.txt
open F, '>bplant.txt' or die;
foreach $word (sort {$bplant{$b} <=> $bplant{$a}} keys %bplant)
{
    $cnt = $bplant{$word};
    print F "$cnt\t$word\n";
}
close F;


# Print the whole word statistics into allwords.txt
open F, '>allwords.txt' or die;
foreach $word (sort {$all{$b} <=> $all{$a}} keys %all)
{
    $cnt = $all{$word};
    print F "$cnt\t$word\n";
}
close F;


# That's all...
